@@ -8,15 +8,15 @@ from flask import Request, jsonify
 from google.cloud import tasks
 
 
-SERVICE_CATALOG = json.loads(os.environ["SERVICE_CATALOG"])
-QUEUE_CATALOG = json.loads(os.environ["QUEUE_CATALOG"])
+SERVICE_CATALOG = json.loads(os.getenv("SERVICE_CATALOG", "{}"))
+QUEUE_CATALOG = json.loads(os.getenv("QUEUE_CATALOG", "{}"))
 TASKS = tasks.CloudTasksClient()
 
 
 def get_service_account_metadata(field, params=None):
     url = (
         "http://metadata.google.internal"
-        "/computeMetadata/v1/instance/service-accounts/default/{field}"
+        f"/computeMetadata/v1/instance/service-accounts/default/{field}"
     )
     return requests.get(
         url=url, headers={"Metadata-Flavor": "Google"}, params=params
