@@ -41,6 +41,15 @@ def valid_chid(chid):
     return False
 
 
+def valid_change_ref(ref):
+    if isinstance(ref, str):
+        parts = ref.split("/")
+        return (
+            len(parts) == 3 and valid_id(parts[0]) and valid_chid("/".join(parts[1:]))
+        )
+    return False
+
+
 def valid_apply_ref(ref):
     return (
         isinstance(ref, str)
